@@ -31,7 +31,7 @@ class DocParser:
         temp_dir="", 
         languages=["est", "eng", "rus"],
         max_file_size = 100,
-        parse_only_extensions = Extension.KNOWN_EXTENSIONS):
+        ignore_digidoc = False):
 
         """
         :param: bool save_attachments: Whether to save email attachments.
@@ -41,7 +41,7 @@ class DocParser:
         :param: str temp_dir: Base directory for files to be saved temporary.
         :param: [str] languages: Tika OCR languages.
         :param: int max_file_size: Maximum file size in MBs that will be parsed. 
-        :param: [str] parse_only_extensions: If the input to the parse function is a directory then only files with given extensions will be parsed
+        :param: [bool] ignore digidoc: Whether digidoc containers should be ignored.
         """
 
         
@@ -50,14 +50,14 @@ class DocParser:
         self.save_documents = save_documents
         self.save_path = save_path
         self.max_file_size = max_file_size
-        self.parse_only_extensions = parse_only_extensions
         self.temp_dir_path = temp_dir
         self.langs = languages
-        self.scanner = DocScanner(parse_only_extensions=parse_only_extensions)
+        self.ignore_digidoc = ignore_digidoc
+        self.scanner = DocScanner()
 
-        if(len(set(Extension.DIGIDOC_EXTENSIONS) & set(parse_only_extensions))> 0):
+        if(self.ignore_digidoc == False):
             if not utils.check_digidoc_exists():
-                raise FileNotFoundError("Digidoc-tool not found. Either exclude digidoc extensions from parse_only_extensions or install the tool.")
+                raise FileNotFoundError("Digidoc-tool not found. Either set ignore_digidoc=True or install the tool.")
 
 
     def create_temp_dir_for_parse(self):
@@ -276,6 +276,9 @@ class DocParser:
             docs_to_parse = []
             # guess extension (it also performs check if extension is known)
             extension = Extension.predict(file_path, file_name=file_name)
+
+            if(self.ignore_digidoc == True and extension in Extension.DIGIDOC_EXTENSIONS):
+                continue
             
             # in case of an arcive, extract all files from it
             if extension in Extension.ARCHIVE_EXTENSIONS:
