@@ -31,14 +31,14 @@ class Extension:
 
 
     @staticmethod
-    def is_supported(file, parse_only_extensions, file_name=None):
+    def is_supported(file, file_name=None):
         """
         Tests if file is supported.
         :return: bool.
         """
         try:
             prediction = Extension.predict(file, file_name=file_name)
-            if prediction in Extension.KNOWN_EXTENSIONS and prediction in parse_only_extensions:
+            if prediction in Extension.KNOWN_EXTENSIONS:
                 return True
         except exceptions.UnsupportedFileError:
             return False
